title:      Meta-Data Extension
id:         100

# markdown

## attr_list
{: class="alert alert-danger"}

## codehilight

    :::yaml
    extension: codehilight

## definition_lists

Apple
:   Pomaceous fruit of plants of the genus Malus in 
    the family Rosaceae.

## fenced

```python
x = 1   # Fenced code block
```

## footnotes

Footnotes[^1] have a label[xx] and the footnote's content.

[^1]: This is a footnote content.
[xx]: A footnote on the label: "xx".

## sane_lists

3. Start
4. End

## smarty_strong

double__underscore__words are OK.
__Strong__ still works.

## smarty

'single quotes',
"double quotes",
<<angle quotes>>,
... ellipsis,
ndash -- and --- mdash
